import axios from "axios";
import config from "../auth_config.json";
import keys from "../api_keys.json";

const instances = Object.entries(keys).reduce(
  (acc, [key, api]) => ({
    ...acc,
    [key]: {
      apiInstance: axios.create({
        baseURL: api.apiBase,
        headers: {
          "content-type": "application/json",
          "x-apikey": api.key,
          "cache-control": "no-cache"
        }
      })
    }
  }),
  {}
);

Object.keys(instances).forEach((instanceKey) => {
  instances[instanceKey].apiInstance.interceptors.response.use((response) => response.data || response);
  instances[instanceKey].get = (path) => instances[instanceKey].apiInstance.get(path);
  instances[instanceKey].post = (path, payload) => instances[instanceKey].apiInstance.post(path, payload);
});

const apiHeaders = {
  "content-type": "application/json",
  "x-apikey": config.apiKey,
  "cache-control": "no-cache"
};

const apiInstance = axios.create({
  baseURL: config.apiBase,
  headers: apiHeaders
});

apiInstance.interceptors.response.use((response) => response.data || response);

const Api = {
  ...instances,
  get: (path) => apiInstance.get(path),
  post: (path, payload) => apiInstance.post(path, payload)
};

export default Api;
